@@ -189,8 +189,9 @@ int PaginateModel::pageCount() const
 {
     if(!m_sourceModel)
         return 0;
-    const int r = (m_sourceModel->rowCount()%m_pageSize == 0) ? 1 : 0;
-    return qCeil(float(m_sourceModel->rowCount())/m_pageSize) - r;
+    const int rc = m_sourceModel->rowCount();
+    const int r = (rc%m_pageSize == 0) ? 1 : 0;
+    return qMax(qCeil(float(rc)/m_pageSize) - r, 1);
 }
 
 bool PaginateModel::hasStaticRowCount() const
@@ -204,8 +205,8 @@ void PaginateModel::setStaticRowCount(bool src)
         return;
     }
 
-    m_hasStaticRowCount = src;
     beginResetModel();
+    m_hasStaticRowCount = src;
     endResetModel();
 }
 
@@ -317,8 +318,8 @@ void PaginateModel::_k_sourceRowsAboutToBeInserted(const QModelIndex& parent, in
     }
 
     if(canSizeChange()) {
-        const int insertedCount = end-start;
         const int newStart = qMax(start-m_firstItem, 0);
+        const int insertedCount = qMin(end-start, pageSize() - newStart -1);
         beginInsertRows(QModelIndex(), newStart, newStart+insertedCount);
     } else {
         beginResetModel();
