@@ -46,6 +46,8 @@ class PackageKitUpdater : public AbstractBackendUpdater
         bool isCancelable() const override;
         bool isProgressing() const override;
         void fetchChangelog() const override;
+        double updateSize() const override;
+        quint64 downloadSpeed() const override;
 
         void proceed() override;
 
@@ -62,13 +64,21 @@ class PackageKitUpdater : public AbstractBackendUpdater
         void finished(PackageKit::Transaction::Exit exit, uint);
         void cancellableChanged();
         void percentageChanged();
-        void printMessage(PackageKit::Transaction::Message type, const QString &message);
         void updateDetail(const QString& packageID, const QStringList& updates, const QStringList& obsoletes, const QStringList& vendorUrls,
                                       const QStringList& bugzillaUrls, const QStringList& cveUrls, PackageKit::Transaction::Restart restart, const QString& updateText,
                                       const QString& changelog, PackageKit::Transaction::UpdateState state, const QDateTime& issued, const QDateTime& updated);
         void packageResolved(PackageKit::Transaction::Info info, const QString& packageId);
+        void repoSignatureRequired(const QString &packageID,
+                                    const QString &repoName,
+                                    const QString &keyUrl,
+                                    const QString &keyUserid,
+                                    const QString &keyId,
+                                    const QString &keyFingerprint,
+                                    const QString &keyTimestamp,
+                                    PackageKit::Transaction::SigType type);
 
     private:
+        void processProceedFunction();
         void itemProgress(const QString &itemID, PackageKit::Transaction::Status status, uint percentage);
         void fetchLastUpdateTime();
         void lastUpdateTimeReceived(QDBusPendingCallWatcher* w);
@@ -85,7 +95,7 @@ class PackageKitUpdater : public AbstractBackendUpdater
         int m_percentage;
         QDateTime m_lastUpdate;
         QStringList m_packagesRemoved;
-        QVector<QString> m_requiredEula;
+        QVector<std::function<PackageKit::Transaction*()>> m_proceedFunctions;
 };
 
 
