@@ -36,6 +36,28 @@ AbstractResource::AbstractResource(AbstractResourcesBackend* parent)
     connect(this, &AbstractResource::stateChanged, this, &AbstractResource::reportNewState);
 }
 
+AbstractResource::~AbstractResource() = default;
+
+QUrl AbstractResource::homepage()
+{
+    return QUrl();
+}
+
+QUrl AbstractResource::helpURL()
+{
+    return QUrl();
+}
+
+QUrl AbstractResource::bugURL()
+{
+    return QUrl();
+}
+
+QUrl AbstractResource::donationURL()
+{
+    return QUrl();
+}
+
 bool AbstractResource::isTechnical() const
 {
     return false;
@@ -223,3 +245,8 @@ QString AbstractResource::displayOrigin() const
 {
     return i18nc("origin (backend name)", "%1 (%2)", origin(), backend()->displayName());
 }
+
+QString AbstractResource::executeLabel() const
+{
+    return i18n("Launch");
+}
