@@ -72,7 +72,12 @@ void ResourcesModel::init(bool load)
     m_updateAction->setIcon(QIcon::fromTheme(QStringLiteral("system-software-update")));
     m_updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
     m_updateAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
+    connect(this, &ResourcesModel::fetchingChanged, m_updateAction, [this](bool fetching) {
+        m_updateAction->setEnabled(!fetching);
+    });
     connect(m_updateAction, &QAction::triggered, this, &ResourcesModel::checkForUpdates);
+
+    connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, this, &QObject::deleteLater);
 }
 
 ResourcesModel::ResourcesModel(const QString& backendName, QObject* parent)
@@ -84,6 +89,7 @@ ResourcesModel::ResourcesModel(const QString& backendName, QObject* parent)
 
 ResourcesModel::~ResourcesModel()
 {
+    s_self = nullptr;
     qDeleteAll(m_backends);
 }
 
@@ -334,8 +340,7 @@ AbstractResource* ResourcesModel::resourceForFile(const QUrl& file)
 void ResourcesModel::checkForUpdates()
 {
     for(auto backend: qAsConst(m_backends))
-        if (!backend->isFetching())
-            backend->checkForUpdates();
+        backend->checkForUpdates();
 }
 
 QVector<AbstractResourcesBackend *> ResourcesModel::applicationBackends() const
